==> messagelib-16.04.2.tar.xz: messagelib-16.04.2/messageviewer/src/viewer/objecttreeviewersource.h <==
/*
  Copyright (C) 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
  Copyright (c) 2009 Andras Mantia <andras@kdab.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef MAILVIEWER_OBJECTTREEVIEWERSOURCE_H
#define MAILVIEWER_OBJECTTREEVIEWERSOURCE_H

#include "objecttreesourceif.h"

class QString;

namespace MessageViewer
{

class ViewerPrivate;

/** An ObjectTreeParser source working on a MailViewer object */
class MailViewerSource : public ObjectTreeSourceIf
{
public:
    explicit MailViewerSource(ViewerPrivate *viewer);
    ~MailViewerSource();
    bool htmlMail() const Q_DECL_OVERRIDE;
    bool decryptMessage() const Q_DECL_OVERRIDE;
    bool htmlLoadExternal() const Q_DECL_OVERRIDE;
    bool showSignatureDetails() const Q_DECL_OVERRIDE;
    void setHtmlMode(Util::HtmlMode mode) Q_DECL_OVERRIDE;
    int levelQuote() const Q_DECL_OVERRIDE;
    const QTextCodec *overrideCodec() Q_DECL_OVERRIDE;
    QString createMessageHeader(KMime::Message *message) Q_DECL_OVERRIDE;
    const AttachmentStrategy *attachmentStrategy() Q_DECL_OVERRIDE;
    HtmlWriter *htmlWriter() Q_DECL_OVERRIDE;
    CSSHelperBase *cssHelper() Q_DECL_OVERRIDE;
    QObject *sourceObject() Q_DECL_OVERRIDE;

    bool autoImportKeys() const Q_DECL_OVERRIDE;
    bool showEmoticons() const Q_DECL_OVERRIDE;
    bool showExpandQuotesMark() const Q_DECL_OVERRIDE;
    const BodyPartFormatterBaseFactory *bodyPartFormatterFactory() Q_DECL_OVERRIDE;
private:
    ViewerPrivate *mViewer;
};

}

#endif

==> messagelib-16.07.80.tar.xz: messagelib-16.07.80/messageviewer/src/viewer/objecttreeviewersource.h <==
/*
  Copyright (C) 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
  Copyright (c) 2009 Andras Mantia <andras@kdab.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef MAILVIEWER_OBJECTTREEVIEWERSOURCE_H
#define MAILVIEWER_OBJECTTREEVIEWERSOURCE_H

#include <MimeTreeParser/ObjectTreeSource>

class QString;

namespace MessageViewer
{

class ViewerPrivate;

/** An ObjectTreeParser source working on a MailViewer object */
class MailViewerSource : public MimeTreeParser::Interface::ObjectTreeSource
{
public:
    explicit MailViewerSource(ViewerPrivate *viewer);
    ~MailViewerSource();
    bool htmlMail() const Q_DECL_OVERRIDE;
    bool decryptMessage() const Q_DECL_OVERRIDE;
    bool htmlLoadExternal() const Q_DECL_OVERRIDE;
    bool showSignatureDetails() const Q_DECL_OVERRIDE;
    void setHtmlMode(MimeTreeParser::Util::HtmlMode mode) Q_DECL_OVERRIDE;
    int levelQuote() const Q_DECL_OVERRIDE;
    const QTextCodec *overrideCodec() Q_DECL_OVERRIDE;
    QString createMessageHeader(KMime::Message *message) Q_DECL_OVERRIDE;
    const MimeTreeParser::AttachmentStrategy *attachmentStrategy() Q_DECL_OVERRIDE;
    MimeTreeParser::HtmlWriter *htmlWriter() Q_DECL_OVERRIDE;
    QObject *sourceObject() Q_DECL_OVERRIDE;

    bool autoImportKeys() const Q_DECL_OVERRIDE;
    bool showEmoticons() const Q_DECL_OVERRIDE;
    bool showExpandQuotesMark() const Q_DECL_OVERRIDE;
    const MimeTreeParser::BodyPartFormatterBaseFactory *bodyPartFormatterFactory() Q_DECL_OVERRIDE;
    MimeTreeParser::Interface::MessagePartRendererPtr messagePartTheme(MimeTreeParser::Interface::MessagePartPtr msgPart) Q_DECL_OVERRIDE;
private:
    ViewerPrivate *mViewer;
};

}

#endif
